/***************************************************************************
                          oooqs.h  -  description
                             -------------------
    begin                : Mon Apr 29 17:48:15 CEST 2002
    copyright            : (C) 2002 by Christian Nitschkowski
    email                : segfault_ii@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef OOOQS_H
#define OOOQS_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <opendialog.h>
#include <qstringlist.h>
#include <prefsdialog.h>

#include <kaboutapplication.h>
#include <kaction.h>
#include <kapp.h>
#include <kconfig.h>
#include <kdialog.h>
#include <kfiledialog.h>
#include <khelpmenu.h>
#include <kpopupmenu.h>
#include <kprocess.h>
#include <ksystemtray.h>

/** OooQs is the base class of the project */
class OooQs : public KSystemTray
{
	Q_OBJECT
public:
	/** construtor */
	OooQs(KAboutData* aboutDta, KDialog* d, QWidget* parent=0, const char *name=0);
	/** destructor */
	~OooQs();
	/** Set the appnameLabels. */
	void setupLabels(bool complete=true);
	/** Returns soffice. */
	QString getSoffice(void);
private: // Private attributes
	/** Saves a pointer to the aboutData */
	KAboutData* aboutData;
	/** Saves the OpenOffice.org icon */
	KPixmap icon;
	/** The actionCollection containing the contextmenu-entrys */
	KActionCollection* actionCollection;
	/** The action that quits the app. */
	KAction* quit;
	/** The action that calls OpenOffice.org Calc. */
	KAction* calc;
	/** The action that calls OpenOffice.org Draw. */
	KAction* draw;
	/** The action that calls OpenOffice.org Impress. */
	KAction* impress;
	/** The action that calls OpenOffice.org Global. */
	KAction* global;
	/** The action that calls OpenOffice.org Math. */
	KAction* math;
	/** The action that calls OpenOffice.org Web. */
	KAction* web;
	/** The action that calls OpenOffice.org Writer. */
	KAction* writer;
	/** The action that calls the openfile-dialog. */
	KAction* file;
	/** The action that menu with the recently opened files. */
	KRecentFilesAction* recent;
	/** The action that calls the preferences-dialog. */
	KAction* preferences;
	/** The about-dialog */
	KDialog* aboutDialog;
	/** The KProcess that starts and control OpenOffice.org in quickstart-mode. */
	KProcess instance;
	/** Saves the path to the soffice startscript/executable */
	QString soffice;
	/** Saves if the quickstart should be enabled */
	bool quickstartEnabled;
	/** The dialog where we'll select what we want to start. */
	openDialog* startDialog;
	/** The dialog where we'll configure the few settings available for oooqs. */
	prefsDialog* preferencesDialog;
	/** The configuration used by oooqs */
	KConfig* config;
	/** The fileOpen-dialog */
	KFileDialog* open;
	/** Used to set the menu-entries to enabled or disabled if the soffice-executable/startstript wasn't found. */
	bool sofficeFound;
	/** The popup-menu displayed on clicking on the icon. */
	KPopupMenu* popupMenu;
	/** The help-menu */
	KHelpMenu* help;
private slots: // Private slots
	/** Asks the user if he wants to start spadmin as root or as the current user. */
	void startSPAdmin();
	/** Opens a KFileDialog that let's you choose some files you want to open. */
	void fileOpen();
	/** Opens the selected file. */
	void openRecent(const KURL& url);
	/** Starts OpenOffice.org Calc with a new file */
	void startCalc();
	/** Starts OpenOffice.org Draw with a new file */
	void startDraw();
	/** Starts OpenOffice.org Impress with a new file */
	void startImpress();
	/** Starts OpenOffice.org with a new global file */
	void startGlobal();
	/** Starts OpenOffice.org Math with a new file */
	void startMath();
	/** Starts OpenOffice.org Web with a new file */
	void startWeb();
	/** Starts OpenOffice.org Writer with a new file */
	void startWriter();
	/** Executes the about-dialog. */
	void showAbout();
	/** Restarts OpenOffice if removed from memory. */
	void restartOffice();
	/** Delete the process. */
	void delProcess(KProcess* process);
	/** Call this to open the start-dialog. */
	void openStart();
	/** Call this to open the preferences-dialog. */
	void openPreferences();
	/** Should be called whenever the configuration changes. */
	void changedConfig();
	/** Call this on doubel clicks on the icon. */
	void mousePressEvent(QMouseEvent*);
	/** Open the last file the user opened using the open-dialog. */
	void openLast();
private:
	/** Call this to (re-)load the config from disk */
	void rereadConfig();
	/** Set the current DoubleClickAction */
	void setDoubleClickAction();
	/** Set the texts on the actions opening the connected module. */
	void updateActions(void);
signals:
	/** Emit when a double click was registered */
	void doubleClick();
public slots: // Public slots
	/** Call this to start OpenOffice.org with the given parameters */
	void startInstances(QStringList);
	/** Call this to clear the list of recent files. */
	virtual void clearURLList();
	/** Return the actionCollection. */
	KActionCollection* getActionCollection();
	/** Kills the OpenOffice.org Quickstart-Instance. */
	void killQuickstart();
public: // Public attributes
	/** The name of the currently selected suite. */
	QString suite;
	/** The text that is displayed on the popupMenu and the listItem. */
	QString calcLabel;
	/** The text that is displayed on the popupMenu and the listItem. */
	QString drawLabel;
	/** The text that is displayed on the popupMenu and the listItem. */
	QString globalLabel;
	/** The text that is displayed on the popupMenu and the listItem. */
	QString impressLabel;
	/** The text that is displayed on the popupMenu and the listItem. */
	QString mathLabel;
	/** The text that is displayed on the popupMenu and the listItem. */
	QString webLabel;
	/** The text that is displayed on the popupMenu and the listItem. */
	QString writerLabel;
	/** The filename of the icon for calc. */
	QString calcIconName;
	/** The filename of the icon for draw. */
	QString drawIconName;
	/** The filename of the icon for global. */
	QString globalIconName;
	/** The filename of the icon for impress. */
	QString impressIconName;
	/** The filename of the icon for math. */
	QString mathIconName;
	/** The filename of the icon for web. */
	QString webIconName;
	/** The filename of the icon for writer. */
	QString writerIconName;
	/** The filename of the icon for admin. */
	QString adminIconName;
	/** The action that calls the start-dialog. */
	KAction* start;
	/** The action that starts spadmin. */
	KAction* admin;
	/** Saves if this is the first start.
	If true when checked, oooqs will be closed. */
	bool firstStart;
};

#endif
