/***************************************************************************
                          prefsdialog.cpp  -  description
                             -------------------
    begin                : Sam Mai 4 2002
    copyright            : (C) 2002 by Christian Nitschkowski
    email                : segfault_ii@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "prefsdialog.h"
#include <oooqs.h>

#include <qlayout.h>
#include <qlistview.h>
#include <qhbuttongroup.h>
#include <qvbox.h>
#include <qwhatsthis.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kmessagebox.h>

#define Icon(x) KGlobal::instance()->iconLoader()->loadIcon(x, KIcon::NoGroup)

prefsDialog::prefsDialog(QWidget *parent, const char *name, QString title ) : KDialogBase(KDialogBase::IconList,
					title, KDialogBase::Help | KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel, KDialogBase::Cancel, parent, name) {

	QVBox* pathes = addVBoxPage( i18n("General"), i18n("General configuration"), Icon("gear"));
	QVBox* modules = addVBoxPage( i18n("Components"), i18n("Select the entries you would like to see in the menu and in the \"%1\"-dialog").arg(i18n("Start with...")), Icon("exec"));
	QVBox* doubleclick = addVBoxPage( i18n("Quick access"), i18n("Select the option you would like to get called when double-clicking on the OOoQs-icon."), Icon("launch"));
	QVBox* advanced = addVBoxPage( i18n("Advanced"), i18n("Advanced settings"), Icon("oooqs"));

	/** Build the pathes-page */
	QWidget* generalContainer = new QWidget(pathes);

	QVBoxLayout* prefDialogLayout = new QVBoxLayout( generalContainer, 11, 6, "prefDialogLayout");
	QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
	prefDialogLayout->addItem( spacer );

	QHButtonGroup* suiteBox = new QHButtonGroup(generalContainer);
	suiteBox->setTitle( i18n("Select your office-suite"));
	suiteBox->layout()->setSpacing( 6 );
	suiteBox->layout()->setMargin( 11 );

	ooffice = new QRadioButton(suiteBox);
	ooffice->setText(i18n("OpenOffice.org"));
	ooffice->setChecked(true);

	soffice = new QRadioButton(suiteBox);
	soffice->setText(i18n("Star Office 6"));

	QSpacerItem* spacer_50 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
	prefDialogLayout->addWidget( suiteBox );
	prefDialogLayout->addItem(spacer_50);

	QGroupBox* GroupBox1 = new QGroupBox( generalContainer, "GroupBox1" );
	GroupBox1->setTitle( i18n( "Select your %1 installpath" ).arg(((OooQs*)parent)->suite) );
	GroupBox1->setColumnLayout(0, Qt::Vertical );
	GroupBox1->layout()->setSpacing( 6 );
	GroupBox1->layout()->setMargin( 11 );
	QGridLayout* GroupBox1Layout = new QGridLayout( GroupBox1->layout() );
	GroupBox1Layout->setAlignment( Qt::AlignTop );

	binary = new KURLRequester( GroupBox1, "binary" );
	binary->fileDialog()->setOperationMode(KFileDialog::Opening);
	binary->setMode(2+8);

	GroupBox1Layout->addWidget( binary, 0, 0 );
	prefDialogLayout->addWidget( GroupBox1 );
	QSpacerItem* spacer_2 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
	prefDialogLayout->addItem( spacer_2 );

	QGroupBox* GroupBox3 = new QGroupBox( generalContainer, "GroupBox3" );
	GroupBox3->setTitle( i18n( "Select your documents-directory" ) );
	GroupBox3->setColumnLayout(0, Qt::Vertical );
	GroupBox3->layout()->setSpacing( 6 );
	GroupBox3->layout()->setMargin( 11 );
	QGridLayout* GroupBox3Layout = new QGridLayout( GroupBox3->layout() );
	GroupBox3Layout->setAlignment( Qt::AlignTop );

	documents = new KURLRequester( GroupBox3, "documents" );
	documents->fileDialog()->setOperationMode(KFileDialog::Opening);
	documents->setMode(2+8);

	GroupBox3Layout->addWidget( documents, 0, 0 );
	prefDialogLayout->addWidget( GroupBox3 );
	QSpacerItem* spacer_3 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
	prefDialogLayout->addItem( spacer_3 );

	QGroupBox* GroupBox4 = new QGroupBox( generalContainer, "GroupBox4" );
	GroupBox4->setTitle( i18n( "Select your templates-directory" ) );
	GroupBox4->setColumnLayout(0, Qt::Vertical );
	GroupBox4->layout()->setSpacing( 6 );
	GroupBox4->layout()->setMargin( 11 );
	QGridLayout* GroupBox4Layout = new QGridLayout( GroupBox4->layout() );
	GroupBox4Layout->setAlignment( Qt::AlignTop );

	templates = new KURLRequester( GroupBox4, "templates" );
	templates->fileDialog()->setOperationMode(KFileDialog::Opening);
	templates->setMode(2+8);

	GroupBox4Layout->addWidget( templates, 0, 0 );
	prefDialogLayout->addWidget( GroupBox4 );
	QSpacerItem* spacer_3_2 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
	prefDialogLayout->addItem( spacer_3_2 );

	/** Build the modules-page */
	QWidget* contentsContainer = new QWidget(modules);

	calc = new QCheckBox( contentsContainer );
	calc->setChecked( TRUE );

	math = new QCheckBox( contentsContainer );
	math->setChecked( TRUE );

	draw = new QCheckBox( contentsContainer );
	draw->setChecked( TRUE );

	web = new QCheckBox( contentsContainer );
	web->setChecked( TRUE );

	impress = new QCheckBox( contentsContainer );
	impress->setChecked( TRUE );

	writer = new QCheckBox( contentsContainer );
	writer->setChecked( TRUE );

	global = new QCheckBox( contentsContainer );
	global->setText( i18n( "Global" ) );
	global->setChecked( TRUE );

	open = new QCheckBox( contentsContainer );
	open->setText( i18n( "Open..." ) );
	open->setChecked( TRUE );

	recent = new QCheckBox( contentsContainer );
	recent->setText( i18n( "Recent files" ) );
	recent->setChecked( TRUE );

	/** Now layout the widgets */
	QGridLayout* modulesLayout = new QGridLayout( contentsContainer, 10, 2 );
	modulesLayout->setSpacing( 6 );
	modulesLayout->setMargin( 11 );
	modulesLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 0, 0, 0, 1 );
	modulesLayout->addWidget( calc, 1, 0 );
	modulesLayout->addWidget( math, 1, 1 );
	modulesLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 2, 2, 0, 1 );
	modulesLayout->addWidget( draw, 3, 0 );
	modulesLayout->addWidget( web, 3, 1 );
	modulesLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 4, 4, 0, 1 );
	modulesLayout->addWidget( impress, 5, 0 );
	modulesLayout->addWidget( writer, 5, 1 );
	modulesLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 6, 6, 0, 1 );
	modulesLayout->addWidget( global, 7, 0 );
	modulesLayout->addWidget( open, 7, 1 );
	modulesLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 8, 8, 0, 1 );
	modulesLayout->addWidget( recent, 9, 0 );
	modulesLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 9, 1 );

	/** Build the doubleclick-page */
	QButtonGroup* stdButtons = new QButtonGroup( doubleclick );
	stdButtons->setTitle("");
	stdButtons->setFrameShape(QGroupBox::NoFrame);
	stdButtons->setFrameShadow(QGroupBox::Plain);
	stdButtons->setColumnLayout(0, Qt::Vertical );
	stdButtons->layout()->setSpacing( 6 );
	stdButtons->layout()->setMargin( 11 );

	stdCalc = new QRadioButton( stdButtons );
	stdCalc->setText( i18n( "Calc" ) );

	stdMath = new QRadioButton( stdButtons );
	stdMath->setText( i18n( "Math" ) );

	stdDraw = new QRadioButton( stdButtons );
	stdDraw->setText( i18n( "Draw" ) );

	stdWeb = new QRadioButton( stdButtons );
	stdWeb->setText( i18n( "Web" ) );

	stdImpress = new QRadioButton( stdButtons );
	stdImpress->setText( i18n( "Impress" ) );

	stdWriter = new QRadioButton( stdButtons );
	stdWriter->setText( i18n( "Writer" ) );

	stdGlobal = new QRadioButton( stdButtons );
	stdGlobal->setText( i18n( "Global" ) );

	stdOpen = new QRadioButton( stdButtons );
	stdOpen->setText( i18n( "Open..." ) );

	stdLast = new QRadioButton( stdButtons );
	stdLast->setText( i18n( "Open last" ) );

	stdStart = new QRadioButton( stdButtons );
	stdStart->setText( i18n( "Start with..." ) );
	stdStart->setChecked( TRUE );

	nothing = new QRadioButton( stdButtons );
	nothing->setText( i18n( "Nothing" ) );

	/** Now layout the widgets */
	QGridLayout* doubleLayout = new QGridLayout( stdButtons->layout(), 13, 2 );
	doubleLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 0, 0, 0, 1 );
	doubleLayout->addWidget( stdCalc, 1, 0 );
	doubleLayout->addWidget( stdMath, 1, 1 );
	doubleLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 2, 2, 0, 1 );
	doubleLayout->addWidget( stdDraw, 3, 0 );
	doubleLayout->addWidget( stdWeb, 3, 1 );
	doubleLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 4, 4, 0, 1 );
	doubleLayout->addWidget( stdImpress, 5, 0 );
	doubleLayout->addWidget( stdWriter, 5, 1 );
	doubleLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 6, 6, 0, 1 );
	doubleLayout->addWidget( stdGlobal, 7, 0 );
	doubleLayout->addWidget( stdOpen, 7, 1 );
	doubleLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 8, 8, 0, 1 );
	doubleLayout->addWidget( stdLast, 9, 0 );
	doubleLayout->addWidget( stdStart, 9, 1 );
	doubleLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 10, 10, 0, 1 );
	doubleLayout->addWidget( nothing, 11, 0 );
	doubleLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 11, 1 );
	doubleLayout->addMultiCell( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 12, 12, 0, 1 );

	/** Build the additional-page */
	QWidget* advancedContainer = new QWidget(advanced);

	enableQuick = new QCheckBox( advancedContainer );

	quickStartFix = new QCheckBox( advancedContainer );

	detailedMenus = new QCheckBox(advancedContainer);
	detailedMenus->setText( i18n( "Use detailed menus" ) );

	saveSelections = new QCheckBox(advancedContainer);
	saveSelections->setText( i18n( "Save selections in the \"%1\"-dialog." ).arg(i18n("Start with...")) );

	QWidget* recentBox = new QWidget(advancedContainer);
	recentLabel = new QLabel( recentBox );
	recentLabel->setText( i18n( "Maximal count of entries in the history" ) );

	maxEntries = new QSpinBox( recentBox );
	maxEntries->setValue( 10 );

	QHBoxLayout* recentLayout = new QHBoxLayout(recentBox, 0, 0 );
	recentLayout->addWidget(recentLabel);
	recentLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
	recentLayout->addWidget(maxEntries);

	clear = new KPushButton( Icon("fileclose"), 0, advancedContainer );
	clear->setText( i18n( "Clear history of recently opened files" ) );
	clear->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));

	QVBoxLayout* additionalLayout = new QVBoxLayout(advancedContainer, 11, 6 );
	additionalLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
	additionalLayout->addWidget(enableQuick);
	additionalLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
	additionalLayout->addWidget(quickStartFix);
	additionalLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
	additionalLayout->addWidget(detailedMenus);
	additionalLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
	additionalLayout->addWidget(saveSelections);
	additionalLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
	additionalLayout->addWidget(recentBox);
	additionalLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
	additionalLayout->addWidget(clear);
	additionalLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ) );

	connect (calc, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (draw, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (global, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (impress, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (math, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (web, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (writer, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (open, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (recent, SIGNAL(toggled(bool)), this, SLOT(contentToggled(bool)));
	connect (this, SIGNAL(cancelClicked()), this, SLOT (cancel()));
	connect (this, SIGNAL(closeClicked()), this, SLOT (cancel()));
	connect (ooffice, SIGNAL(toggled(bool)), this, SLOT (updateSuite(bool)));
	connect (enableQuick, SIGNAL(toggled(bool)), quickStartFix, SLOT (setEnabled(bool)));
}
prefsDialog::~prefsDialog(){
}

/** Called when the user clicks on OK */
void prefsDialog::accept(){
	slotApply();
	if (binary->url()){
		hide();
		close();
	}
}
/** Update the labels and checkboxes when the suite has changed. */
void prefsDialog::updateStrings(void){
	((QGroupBox*)binary->parent())->setTitle(i18n( "Select your %1 installpath" ).arg(((OooQs*)parent())->suite) );
	enableQuick->setText(i18n( "Use %1's Quickstart-mode (requires some memory)" ).arg(((OooQs*)parent())->suite) );
	quickStartFix->setText( i18n( "Enable quickstart-fix (will break session managing of %1)" ).arg(((OooQs*)parent())->suite) );
	calc->setText(((OooQs*)parent())->calcLabel);
	draw->setText(((OooQs*)parent())->drawLabel);
	global->setText(((OooQs*)parent())->globalLabel);
	impress->setText(((OooQs*)parent())->impressLabel);
	math->setText(((OooQs*)parent())->mathLabel);
	web->setText(((OooQs*)parent())->webLabel);
	writer->setText(((OooQs*)parent())->writerLabel);
	stdCalc->setText(((OooQs*)parent())->calcLabel);
	stdDraw->setText(((OooQs*)parent())->drawLabel);
	stdGlobal->setText(((OooQs*)parent())->globalLabel);
	stdImpress->setText(((OooQs*)parent())->impressLabel);
	stdMath->setText(((OooQs*)parent())->mathLabel);
	stdWeb->setText(((OooQs*)parent())->webLabel);
	stdWriter->setText(((OooQs*)parent())->writerLabel);

	/** Set the whatsthis-help in the base-page */
	QWhatsThis::add((QHButtonGroup*)ooffice->parent(), i18n("Here you can select which office suite you're using. The texts and icons used by Quickstarter will be set accordingly to your selection. If you don't know which suite you're using, leave the default value. It won't affect the programs functionality."));
	QWhatsThis::add((QGroupBox*)binary->parent(), i18n("Here you'll have to enter the directory where your %1 is installed. This can be either your personal directory or the system-wide installation directory. The only requirement is that a file \"soffice\" is located in the given directory that will start your %2 with the parameters given to the file.").arg(((OooQs*)parent())->suite).arg(((OooQs*)parent())->suite));
	QWhatsThis::add((QGroupBox*)documents->parent(), i18n("Here you can enter a directory where your documents are saved. This directory will be the standard-directory when you want to open a file using the open-entry in the context-menu."));
	QWhatsThis::add((QGroupBox*)templates->parent(), i18n("Here you can enter a directory where your templates are saved. This directory will be shown when you open the %1-tab in the \"%2\"-dialog.").arg(i18n("Templates")).arg(i18n("Start with...")));

	/** Set the whatsthis-help in the modules-page */
	QWhatsThis::add(calc, i18n("Enable if you want to use %1, so that it can be called from the context menu or from the \"%2\"-dialog.").arg(calc->text()).arg(((OooQs*)parent())->start->text()));
	QWhatsThis::add(draw, i18n("Enable if you want to use %1, so that it can be called from the context menu or from the \"%2\"-dialog.").arg(draw->text()).arg(((OooQs*)parent())->start->text()));
	QWhatsThis::add(global, i18n("Enable if you want to use %1, so that it can be called from the context menu or from the \"%2\"-dialog.").arg(global->text()).arg(((OooQs*)parent())->start->text()));
	QWhatsThis::add(impress, i18n("Enable if you want to use %1, so that it can be called from the context menu or from the \"%2\"-dialog.").arg(impress->text()).arg(((OooQs*)parent())->start->text()));
	QWhatsThis::add(math, i18n("Enable if you want to use %1, so that it can be called from the context menu or from the \"%2\"-dialog.").arg(math->text()).arg(((OooQs*)parent())->start->text()));
	QWhatsThis::add(web, i18n("Enable if you want to use %1, so that it can be called from the context menu or from the \"%2\"-dialog.").arg(web->text()).arg(((OooQs*)parent())->start->text()));
	QWhatsThis::add(writer, i18n("Enable if you want to use %1, so that it can be called from the context menu or from the \"%2\"-dialog.").arg(writer->text()).arg(((OooQs*)parent())->start->text()));
	QWhatsThis::add(open, i18n("Enable if you want to be able to open files using the quickstarter."));
	QWhatsThis::add(recent, i18n("Enable if you want to get a history of the last opened files using the quickstarter."));

	/** Set the whatsthis-help in the doubleclicks-page */
	QWhatsThis::add(stdCalc, i18n("Select to start %1 by double clicking on the OOoQs-icon.").arg(stdCalc->text()));
	QWhatsThis::add(stdDraw, i18n("Select to start %1 by double clicking on the OOoQs-icon.").arg(stdDraw->text()));
	QWhatsThis::add(stdGlobal, i18n("Select to start %1 by double clicking on the OOoQs-icon.").arg(stdGlobal->text()));
	QWhatsThis::add(stdImpress, i18n("Select to start %1 by double clicking on the OOoQs-icon.").arg(stdImpress->text()));
	QWhatsThis::add(stdMath, i18n("Select to start %1 by double clicking on the OOoQs-icon.").arg(stdMath->text()));
	QWhatsThis::add(stdWeb, i18n("Select to start %1 by double clicking on the OOoQs-icon.").arg(stdWeb->text()));
	QWhatsThis::add(stdWriter, i18n("Select to start %1 by double clicking on the OOoQs-icon.").arg(stdWriter->text()));
	QWhatsThis::add(stdLast, i18n("Select to start the last opened file by double clicking on the OOoQs-icon."));
	QWhatsThis::add(stdOpen, i18n("Select to open the file-open-dialog by double clicking on the OOoQs-icon."));
	QWhatsThis::add(nothing, i18n("Select to do nothing on double clicks on the OOoQs-icon."));
	QWhatsThis::add(stdStart, i18n("Select to show the \"%1\"-dialog by double clicking on the OOoQs-icon. You can use it to start the activated %2 modules, to start with different wizards if %3 %4 is activated or to start with templates which are stored in the directory you selected earlier in the ...-tab.").arg(((OooQs*)parent())->start->text()).arg(((OooQs*)parent())->suite).arg(((OooQs*)parent())->suite).arg(writer->text()));

	/** Set the whatsthis-help in the advanced-page */
	QWhatsThis::add(enableQuick, i18n("Select to use %1's quickstart-mode. This will speed up the startup-time of new %2 instaces a lot, at the cost of memory. OpenOffice.org 1.0 needs 72 MB of RAM for the quickstart-mode. After applying the changes, you should wait a few seconds to let %3 load the needed data into memory.").arg(((OooQs*)parent())->suite).arg(((OooQs*)parent())->suite).arg(((OooQs*)parent())->suite));
	QWhatsThis::add(quickStartFix, i18n("Select to enable a workaround in your startkde-script. (Read the INSTALL-file to get an explanation how to do this). This will break session-management for %1").arg(((OooQs*)parent())->suite));
	QWhatsThis::add(detailedMenus, i18n("Select to show the type of the application in the menus. For example, a setting without this option will result in a menu-entry like %1 %2. A setting with this option enabled will give you %3 %4 (%5).").arg(((OooQs*)parent())->suite).arg(i18n("Calc")).arg(((OooQs*)parent())->suite).arg(i18n("Calc")).arg(i18n("Spreadsheet")));
	QWhatsThis::add(saveSelections, i18n("Select to save your selections in the \"%1\"-dialog. They will be restored when the Quickstarter is started again any time later.").arg(i18n("Start with...")));
	QWhatsThis::add(((QHBox*)maxEntries->parent()), i18n("Set the number of items shown in the \"%1\"-menu. If this option is disabled, enable \"%2\" in the \"%3\"-tab.").arg(recent->text()).arg(recent->text()).arg(i18n("Modules")));
	QWhatsThis::add(clear, i18n("Click here to clear the list of \"%1\"").arg(recent->text()));
}
/** Called when a new page is about to be shown. */
void prefsDialog::changedPage(QWidget* newPage){
	if (newPage == binary->parent()){
		setHelp("configuration");
	}
	if (newPage == calc->parent()){
		setHelp("components");
	}
	if (newPage == stdCalc->parent()){
		setHelp("quick-access");
	}
	if (newPage == clear->parent()){
		setHelp("advanced");
	}
}
/** Restore settings from config-file when the user cancels the new settings */
void prefsDialog::cancel(){
	KConfig* kickerconf = new KConfig("kickerrc", true);
	KConfig* config = KGlobal::config();

	kickerconf->setGroup("menus");
	/** Reparse the configuration to be shure that the data we use is up to date */
	config->reparseConfiguration();
	config->setGroup("General options");
	/** Set the widgets in the preferences dialog to the current values */
	binary->setURL(config->readEntry("exec"));
	enableQuick->setChecked(config->readBoolEntry("quickstart"));
	maxEntries->setValue(config->readUnsignedNumEntry("maxRecentFiles"));
	documents->setURL(config->readEntry("documents"));
	templates->setURL(config->readEntry("templates"));
	ooffice->setChecked(config->readBoolEntry("suite", true));
	soffice->setChecked(!(config->readBoolEntry("suite", false)));
	detailedMenus->setChecked(config->readBoolEntry("detailed", kickerconf->readBoolEntry("DetailedMenuEntries")));
	saveSelections->setChecked(config->readBoolEntry("save", kickerconf->readBoolEntry("DetailedMenuEntries")));
	config->setGroup("Modules");
	calc->setChecked(config->readBoolEntry("calc"));
	draw->setChecked(config->readBoolEntry("draw"));
	impress->setChecked(config->readBoolEntry("impress"));
	global->setChecked(config->readBoolEntry("global"));
	math->setChecked(config->readBoolEntry("math"));
	web->setChecked(config->readBoolEntry("web"));
	writer->setChecked(config->readBoolEntry("writer"));
	open->setChecked(config->readBoolEntry("open"));
	recent->setChecked(config->readBoolEntry("recent"));
	config->setGroup("Additional");
	stdCalc->setChecked(config->readBoolEntry("stdCalc"));
	stdDraw->setChecked(config->readBoolEntry("stdDraw"));
	stdImpress->setChecked(config->readBoolEntry("stdImpress"));
	stdGlobal->setChecked(config->readBoolEntry("stdGlobal"));
	stdMath->setChecked(config->readBoolEntry("stdMath"));
	stdWeb->setChecked(config->readBoolEntry("stdWeb"));
	stdWriter->setChecked(config->readBoolEntry("stdWriter"));
	stdOpen->setChecked(config->readBoolEntry("stdOpen"));
	stdLast->setChecked(config->readBoolEntry("stdLast"));
	stdStart->setChecked(config->readBoolEntry("stdStart"));
	nothing->setChecked(config->readBoolEntry("nothing"));
}
/** Updates OooQs::suite and updates the strings in the dialog accordingly. */
void prefsDialog::updateSuite(bool ooo){
	if (ooo){
		((OooQs*)parent())->suite=i18n("OpenOffice.org");
	}else{
		((OooQs*)parent())->suite=i18n("Star Office");
	}
	((OooQs*)parent())->setupLabels(0);
}
/** Called when the user clicks on OK or Apply */
void prefsDialog::slotApply(){
	if (binary->url()){
		emit success();
	}
}
/** Called when one of the checkboxes in contents get toggled. */
void prefsDialog::contentToggled(bool state){
	if (sender() == calc){
		stdCalc->setEnabled(state);
		if ((stdCalc->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
	if (sender() == draw){
		stdDraw->setEnabled(state);
		if ((stdDraw->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
	if (sender() == global){
		stdGlobal->setEnabled(state);
		if ((stdGlobal->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
	if (sender() == impress){
		stdImpress->setEnabled(state);
		if ((stdImpress->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
	if (sender() == math){
		stdMath->setEnabled(state);
		if ((stdMath->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
	if (sender() == web){
		stdWeb->setEnabled(state);
		if ((stdWeb->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
	if (sender() == writer){
		stdWriter->setEnabled(state);
		if ((stdWriter->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
	if (sender() == open){
		stdOpen->setEnabled(state);
		stdLast->setEnabled(state);
		recent->setEnabled(state);
		if (!state){
			recent->setChecked(false);
		}
		recentLabel->setEnabled(state);
		maxEntries->setEnabled(state);
		clear->setEnabled(state);
		if ((stdOpen->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
		if ((stdLast->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
	if (sender() == recent){
		stdLast->setEnabled(state);
		recentLabel->setEnabled(state);
		maxEntries->setEnabled(state);
		clear->setEnabled(state);
		if ((stdLast->isChecked()) && (!state)){
			nothing->setChecked(true);
		}
	}
}
